.. Bluemath-Toolkit documentation master file, created by
   sphinx-quickstart on Tue Feb 18 18:36:30 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

BlueMath-tk: A Python Library for Coastal Climate Hazards
=========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   installation
   contribute
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`